pub enum CodegenError {
Io {
path: PathBuf,
source: Error,
},
InvalidDescriptor {
detail: String,
},
UnsupportedSchema {
path: PathBuf,
detail: String,
},
UnsupportedInteraction {
operation: String,
interaction: String,
},
InvalidPortableValue {
path: String,
detail: String,
},
GeneratedArtifactDrift {
path: PathBuf,
},
}Expand description
Errors produced while parsing, validating, or generating a contract.
Variants
Io
A file could not be read.
InvalidDescriptor
Descriptor or Schema data is malformed.
UnsupportedSchema
A Schema cannot be used by the portable value profile.
UnsupportedInteraction
A Descriptor interaction is not supported by the generated language bindings.
InvalidPortableValue
A JSON value would be lossy when represented by JavaScript numbers.
GeneratedArtifactDrift
A checked-in generated artifact differs from its source.