pub enum CompatibilityError {
IdentityChanged {
from: String,
to: String,
},
VersionNotAdvanced {
from: String,
to: String,
},
BreakingChanges {
changes: Vec<String>,
},
}Expand description
Reasons why a Descriptor evolution is not safe for an existing Capability series.
Variants
IdentityChanged
The two files do not describe the same Capability series.
VersionNotAdvanced
The new Descriptor is not newer than the old one.
BreakingChanges
The change is not allowed by the old series and requires a new major.