pub fn check_projection(
descriptor_path: &Path,
language: ProjectionLanguage,
output_path: &Path,
) -> Result<(), CodegenError>Expand description
Fails when one selected language projection is not exactly reproducible.
pub fn check_projection(
descriptor_path: &Path,
language: ProjectionLanguage,
output_path: &Path,
) -> Result<(), CodegenError>Fails when one selected language projection is not exactly reproducible.