pub fn check_source_snapshot(
snapshot: &CapabilitySnapshot,
descriptor_path: &Path,
) -> Result<(), CodegenError>Expand description
Fails unless every committed Descriptor and Schema byte matches compiled source.
pub fn check_source_snapshot(
snapshot: &CapabilitySnapshot,
descriptor_path: &Path,
) -> Result<(), CodegenError>Fails unless every committed Descriptor and Schema byte matches compiled source.