pub fn generate_browser_request_client(
path: &Path,
) -> Result<String, CodegenError>Expand description
Generates an executable browser request client from the same validated Descriptor IR used by the checked-in Rust and TypeScript bindings.
pub fn generate_browser_request_client(
path: &Path,
) -> Result<String, CodegenError>Generates an executable browser request client from the same validated Descriptor IR used by the checked-in Rust and TypeScript bindings.