generate_module_projection

Function generate_module_projection 

pub fn generate_module_projection(
    path: &Path,
    language: ProjectionLanguage,
    module: &str,
) -> Result<GeneratedProjection, CodegenError>
Generate a Rust projection loaded as a normal module through #[path]. module is the exact public path from the consuming crate’s root.