pub struct Descriptor { /* private fields */ }Expand description
A validated, self-contained portable Capability Descriptor.
Implementations
Sourceimpl Descriptor
impl Descriptor
Sourcepub fn capability_id(&self) -> &str
pub fn capability_id(&self) -> &str
Returns the stable Capability series identity, including its major.
Sourcepub const fn capability_major(&self) -> u64
pub const fn capability_major(&self) -> u64
Returns the major encoded in the Capability identity.
Sourcepub fn descriptor_digest(&self) -> &str
pub fn descriptor_digest(&self) -> &str
Returns the canonical digest of the resolved Descriptor and Schemas.
Sourcepub const fn portable(&self) -> bool
pub const fn portable(&self) -> bool
Returns whether the Capability is intended to cross Runtime Adapters.
Sourcepub const fn cross_lane_transfer(&self) -> bool
pub const fn cross_lane_transfer(&self) -> bool
Returns whether generated native values support transfer across Execution Lanes.
Sourcepub fn operation_names(&self) -> Vec<&str>
pub fn operation_names(&self) -> Vec<&str>
Returns the stable Operation names in deterministic lexical order.